@@ -27,13 +27,15 @@ try:
     import userprofile
     import util
     from config import *
+    import debuglog
 except:
     from sabayon import userprofile
     from sabayon import util
     from sabayon.config import *
+    from sabayon import debuglog
 
 def dprint (fmt, *args):
-    util.debug_print (util.DEBUG_PANELDELEGATE, fmt % args)
+    debuglog.debug_log (False, debuglog.DEBUG_LOG_DOMAIN_PANEL_DELEGATE, fmt % args)
 
 PANEL_LAUNCHER_DIR = ".gnome2/panel2.d/default/launchers"
 
@@ -206,7 +208,7 @@ class PanelDelegate (userprofile.SourceDelegate):
 			else:
 				desktop_file = PANEL_LAUNCHER_DIR + "/" + launcher_location
 			launcher = xdg.DesktopEntry.DesktopEntry(desktop_file)
-			self.name = launcher.getName() + _(" launcher")
+			self.name = _("%s launcher") % launcher.getName()
 		elif self.object_type == "action-applet":
 			action_type = self.client.get_string (PANEL_KEY_BASE + "/objects/" + id + "/action_type")
 			if action_type == "lock":
