@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 #
 # Copyright (C) 2005 Red Hat, Inc.
 #
@@ -29,6 +27,7 @@ import cache
 import random
 import ldap
 import socket
+import debuglog
 
 defaultConf="""<profiles>
   <default profile=""/>
@@ -40,8 +39,7 @@ defaultConf="""<profiles>
 cache.initialize()
 
 def dprint (fmt, *args):
-    util.debug_print (util.DEBUG_USERDB, fmt % args)
-
+    debuglog.debug_log (False, debuglog.DEBUG_LOG_DOMAIN_USER_DB, fmt % args)
 
 def get_setting (node, setting, default = None, convert_to = str):
     a = node.hasProp(setting)
@@ -49,7 +47,8 @@ def get_setting (node, setting, default = None, convert_to = str):
         try:
             return convert_to (a.content)
         except:
-            raise UserDatabaseException(_("invalid type for setting %s in %s") % (setting, node.nodePath()))
+	    np = node.nodePath()
+            raise UserDatabaseException(_("invalid type for setting %(setting)s in %(np)s") % (setting, np))
     return default
 
 def expand_string (string, attrs):
@@ -437,6 +436,26 @@ class UserDatabase:
 	# TODO: also list remote profiles as found in self.doc
 	return list
 
+    def is_sabayon_controlled (self, username):
+        """Return True if user's configuration was ever under Sabayon's
+        control.
+        """
+        profile = self.__ldap_query ("profilemap", {"u":username, "h":socket.getfqdn()})
+
+        if profile:
+            return True
+        
+        try:
+            query = "/profiles/user[@name='%s']" % username
+            user = self.doc.xpathEval(query)[0]
+        except:
+            return False
+
+        if user:
+            return True
+
+        return False
+
     def get_users (self):
         """Return the list of users on the system. These should
         be real users - i.e. should not include system users
@@ -457,6 +476,8 @@ class UserDatabase:
 		    continue
 		if user[6] == "" or string.find(user[6], "nologin") != -1:
 		    continue
+                if user[0][len (user[0]) - 1] == "$":  # ADS hosts
+                    continue
 		list.append(user[0])
 	    except:
 		pass
